#!/bin/bash

################################################################################
## replace hostname with mac address
################################################################################

NET_DEVICE=$(ip r l scope global | awk '{print $5}')
NEW_HOSTNAME=$(ifconfig $NET_DEVICE | grep -oi '[0-9A-F]\{2\}\(:[0-9A-F]\{2\}\)\{5\}' | sed 's,:,,g')

logger -t late-command "setting hostname to mac address"

sed -i 's,PRESEED,'${NEW_HOSTNAME}',g' /etc/hosts
sed -i 's,PRESEED,'${NEW_HOSTNAME}',g' /etc/hostname

################################################################################
## grub options
################################################################################

sed -i 's,quiet splash,,' /etc/default/grub
update-grub

################################################################################
## install Docker
################################################################################

#curl -sSL https://get.docker.com/ | sh
apt install docker.io

# install portainer
#docker run -d -p 9000:9000 portainer/portainer
#run with root access to host socket.
docker run -d -p 9000:9000 --restart always -v /var/run/docker.sock:/var/run/docker.sock -v /opt/portainer:/data portainer/portainer

################################################################################
## install Gitlab CI Multirunner
################################################################################

#curl -L https://packages.gitlab.com/install/repositories/runner/gitlab-ci-multi-runner/script.deb.sh | bash
#apt-get install gitlab-ci-multi-runner

################################################################################
## add gitlab-ci user to docker group
################################################################################

#usermod -aG docker gitlab-ci

################################################################################
## add some handy bash aliases
################################################################################

#cat > /etc/profile.d/docker.sh << EOF
#alias 'docker-clean-containers=docker rm $(docker ps -a -q)'
#alias 'docker-clean-images=docker rmi $(docker images -f "dangling=true" -q)'
#alias 'docker-clean-volumes=docker volume rm `docker volume ls -q -f dangling=true`'
#EOF

################################################################################
## force user gitlab-ci to change it's password
################################################################################

#chage -d 0 gitlab-ci

#shutdown at the end
shutdown -h now
